/*
   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <QObject>

class SieveImapInstanceInterfaceManagerTest : public QObject
{
    Q_OBJECT
public:
    explicit SieveImapInstanceInterfaceManagerTest(QObject *parent = nullptr);
    ~SieveImapInstanceInterfaceManagerTest() override = default;
private Q_SLOTS:
    void shouldHaveDefaultValue();
    void shouldAssignSieveImapInstanceInterface();
};

